Changelog
=========


0.2.1 (2017-06-10)
------------------
- Initial doc setup. [Serkan Hosca]


0.2.0 (2017-06-10)
------------------
- Refactor field mapping and object fetching and more tests. [Serkan
  Hosca]


0.1.4 (2017-06-09)
------------------
- Respect allow_null. [Serkan Hosca]


0.1.2 (2017-06-08)
------------------
- Mark all columns read only when allow_nested_updates is false. [Serkan
  Hosca]


0.1.1 (2017-06-07)
------------------
- Fix composite serializer. [Serkan Hosca]


0.1.0 (2017-06-06)
------------------
- Add more tests and generic api fixes. [Serkan Hosca]


0.0.6 (2017-06-05)
------------------
- Bump version. [Serkan Hosca]
- Add missing dep and add pypi badge. [Serkan Hosca]
- Add more tests for composite routes. [Serkan Hosca]


0.0.5 (2017-06-05)
------------------
- Bump version. [Serkan Hosca]
- Add route tests. [Serkan Hosca]


0.0.4 (2017-06-05)
------------------
- Add pre-commit. [Serkan Hosca]
- Move GenericAPIView. [Serkan Hosca]
- Fix Readme. [Serkan Hosca]


0.0.2 (2017-06-02)
------------------
- Fix setup publish and make clean. [Serkan Hosca]
- Added viewsets and version bump. [Serkan Hosca]
- Update readme. [Serkan Hosca]


0.0.1 (2017-06-02)
------------------
- Fix readme. [Serkan Hosca]
- Added initial readme. [Serkan Hosca]
- Add travis. [Serkan Hosca]
- Initial commit. [Serkan Hosca]


